Crate luau_printf

Crate luau_printf 

Modules

locale

Macros

sprintf
A macro to format a byte string with C-locale formatting rules.

Structs

BStr
Musl snprintf-compatible byte formatting for Luau, forked from fish-printf. A wrapper for &[u8] that provides convenient string oriented trait impls.
BString
Musl snprintf-compatible byte formatting for Luau, forked from fish-printf. A wrapper for Vec<u8> that provides convenient string oriented trait impls.

Enums

Arg
Printf argument types. Note no implementation of ToArg constructs the owned string variant; callers can do so explicitly.
Error
Possible errors from printf.

Traits

ToArg
Conversion from a raw value to a printf argument.

Functions

printf_c_locale
Formats a byte string using the provided format specifiers and arguments, using the C locale.
printf_c_locale_to_slice
Formats a byte string into a fixed-size byte slice using C-locale formatting rules.
printf_locale_to_slice
sprintf_locale
Formats a byte string using the provided format specifiers, arguments, and locale.