printf_c_locale_to_slice

Function printf_c_locale_to_slice 

pub fn printf_c_locale_to_slice(
    buffer: &mut [u8],
    fmt: &BStr,
    args: &mut [Arg<'_>],
) -> Result<usize, Error>
Formats a byte string into a fixed-size byte slice using C-locale formatting rules.

The returned count is the number of bytes that would have been written without truncation. Bytes that do not fit in buffer are discarded.